@@ -19,7 +19,7 @@ use ffi::*;
 /// Module context.
 ///
 /// Can contain only one module and provides functions for manipulating it.
-pub struct Context(InnerContext);
+pub struct Context(ContextPointer);
 
 unsafe impl Send for Context {}
 unsafe impl Sync for Context {}
@@ -55,7 +55,7 @@ impl Context {
     }
 
     /// Returns a raw pointer to the inner context.
-    pub fn as_ptr(&mut self) -> InnerContext {
+    pub fn as_ptr(&mut self) -> ContextPointer {
         self.0
     }
 
@@ -66,7 +66,7 @@ impl Context {
     ///
     /// [`new`]: Self::new
     /// [`xm_create_context_safe`]: xm_create_context_safe
-    pub unsafe fn from_ptr(pointer: InnerContext) -> Self {
+    pub unsafe fn from_ptr(pointer: ContextPointer) -> Self {
         Self(pointer)
     }
 
